% Quokka3 settingsfile representing a single-junction perovskite solar cell
% cell properties calibrated to the top-cell in:
% Messmer et al., "Toward more reliable measurement procedures of perovskite-silicon tandem solar cells: The role of transient device effects and measurement conditions", PiP 2024, https://doi.org/10.1002/pip.3782

% the model is simplified from the original publication mainly by using a fixed workfunction as the HTL boundary
% tunneling of holes at the ETL interface is represented by a simple SRH surface recombination
% Sn is assumed very high (thermal velocity) to be non-limiting, representing an effectively unlimited suppy of electrons in the ETL
% Sp = 3 cm/s is found to match Voc

% Support by Christoph Messmer (Fraunhofer ISE) is acknowledged for calibrating this example to the original Sentaurus Device simulations

% this examples uses the transient solver to simulate luminescence decay after a laser pulse
% as there is no ion movement within the short decay time, ions are not transiently solved, but preconditioned using the pre-bias functionality

% perovskite n&k values required for the laser generation and luminescence modeling are taken from the KAUST tandem example

% (c) 2025 Andreas Fell

Syntax = 'generic';

Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 1;
Domain.Wz = 450 nm;

Solver.Electrical.BulkModelType = 'full';
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.VocGuess = 1.2;
Solver.Electrical.IonModelType = 'pre-bias';
Solver.IonPreBias.Type = 'OC';
Solver.Illumination.Enable = 1;
Solver.Luminescence.Enable = 1;

Optical.Luminescence.WavelengthRangeType = 'user';
Optical.Luminescence.WavelengthRangeUser = [650:5:850];

Solver.SolutionType = 'transient';
Solver.Transient.JVType= 'OC';
Solver.Transient.GenerationScale.Type = 'XY';
Solver.Transient.GenerationScale.X=[0 100e-9 101e-9 1e6] s; % a 100ns laser pulse
Solver.Transient.GenerationScale.Y = [1 1 0 0];
Solver.Transient.SteadyStateEHTransportOnset = 10ms; % solves electron-hole transport as quasi-steady-state after this time, sensible to set only in combination with mobile ions
Solver.Transient.MaxInitialTimeStep = 1e-15;
Solver.Transient.TimeSpan = 5ms; % time span to simulate
Solver.Transient.StartType = 'intrinsic'; % start condition: intrinsic (i.e. 0 V and 0 Generation)
Solver.Transient.MaxChange = 0.05;

% sweeping the pre-bias type, i.e. the preconditioning
% 'intrinsic' represents a device being stored very long in the dark
% 'OC' represents a device being held at OC for very long, and then quickly applying the laser pulse
Sweep.Enable = 1;
Sweep.NGroups = 1;
Sweep.GroupA(1).Parameter = 'Solver.IonPreBias.Type';
Sweep.GroupA(1).Values = ['intrinsic','OC'];


Thermal.T = 298.15;

Optical.GenerationModelType = 'Text-Z';
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'const';
Optical.TextZ.FrontText.Text.Const = 0.9; % 1-reflection at the laser wavelength
Optical.TextZ.FrontZ.Type = 'Green02-limit'; % doesn't matter for laser illumination with wavelength well above band-gap
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'monochromatic';
Optical.FrontIllumination.Spectrum.MonoWavelength = 600;
Optical.FrontIllumination.Spectrum.MonoFlux = 1e17; % photon flux corresponding to a generation scale of 1

Bulk.Material = 'PVK';
Bulk.BackgroundDoping.SettingType = 'NA-ND';
Bulk.BackgroundDoping.NA = 1e10;
Bulk.BackgroundDoping.ND = 1e10;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 1 us;
Bulk.Electrical.Recombination.SRH(1).taup = 1 us;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;
Bulk.Mesh.Quality = 'standard';

SkinFeature(1).Name = 'HTL';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).ElectricalModelType = 'detailed';
SkinFeature(1).Detailed.Mesh.Quality = 'standard';
SkinFeature(1).Layer(1).Name = 'near-surface';
SkinFeature(1).Layer(1).Type = 'near-surface';
SkinFeature(1).Layer(2).Name = 'ITO';
SkinFeature(1).Layer(2).Type = 'transport';
SkinFeature(1).Layer(2).ConductionType = 'p-type';
SkinFeature(1).Layer(2).Thickness = 20nm;
SkinFeature(1).Layer(2).TLModelType = 'metal-like';
SkinFeature(1).Layer(2).Interface.OhmicResistivity = 1e10; % parallel to thermionic emission; very high means no influence, only thermionix emission
SkinFeature(1).Layer(2).Interface.BarrierHeightType = 'from workfunction';
SkinFeature(1).Layer(2).WorkFunction = 5.9;


SkinFeature(2).Name = 'ETL';
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).ElectricalModelType = 'detailed';
SkinFeature(2).Detailed.Mesh.Quality = 'standard';
SkinFeature(2).Layer(1).Name = 'near-surface';
SkinFeature(2).Layer(1).Type = 'near-surface';
SkinFeature(2).Layer(1).SurfaceRecombination.Type = 'S';
SkinFeature(2).Layer(1).SurfaceRecombination.Sp = 3;
SkinFeature(2).Layer(1).SurfaceRecombination.Sn = 2e7; % thermal velocity 
SkinFeature(2).Layer(2).Name = 'C60';
SkinFeature(2).Layer(2).Type = 'transport';
SkinFeature(2).Layer(2).ConductionType = 'n-type';
SkinFeature(2).Layer(2).Thickness = 10nm;
SkinFeature(2).Layer(2).Material = 'C60';
SkinFeature(2).Layer(2).TLModelType = 'analytic band-bending';
SkinFeature(2).Layer(2).EactType = 'from DOS and doping';
SkinFeature(2).Layer(2).DopingDensityType = 'user';
SkinFeature(2).Layer(2).DopingDensity = 1e19;
SkinFeature(2).Layer(2).Interface.OhmicResistivity = 1e10;



Material.User(1).Name = 'PVK';
Material.User(1).ElectronAffinity = 4.25;
Material.User(1).RelativePermittivity = 24.2;
Material.User(1).BandGap = 1.64;
Material.User(1).Nc = 7e18;
Material.User(1).Nv = 2.5e18;
Material.User(1).ElectronMobility = 2;
Material.User(1).HoleMobility = 2;
Material.User(1).Crad = 0.4899; % 3e-11 cm3/s times ni^2: Brad * Nc * Nv * exp(BandGap/Vt)
Material.User(1).nkModel = 'user';
Material.User(1).nk.n.Type = 'file';
Material.User(1).nk.n.File = 'PVK_n.csv';
Material.User(1).nk.k.Type = 'file';
Material.User(1).nk.k.File = 'PVK_k.csv';
Material.User(1).IonsEnable = 1;
Material.User(1).N0an = 6e16;
Material.User(1).N0cat = 6e16;
Material.User(1).AnionMobility = 3.86e-8; % 1e-9 / Vt
Material.User(1).CationMobility = 3.86e-14; % 1e-15 / Vt

Material.User(2).Name = 'C60';
Material.User(2).ElectronAffinity = 4.45;
Material.User(2).RelativePermittivity = 5;
Material.User(2).BandGap = 1.97;
Material.User(2).Nc = 9.91e20;
Material.User(2).Nv = 9.91e20;
