% Quokka3 settingsfile representing a single-junction perovskite solar cell
% cell properties calibrated to the top-cell in:
% Messmer et al., "Toward more reliable measurement procedures of perovskite-silicon tandem solar cells: The role of transient device effects and measurement conditions", PiP 2024, https://doi.org/10.1002/pip.3782

% the model is simplified from the original publication mainly by using a fixed workfunction as the HTL boundary
% tunneling of holes at the ETL interface is represented by a simple SRH surface recombination
% Sn is assumed very high (thermal velocity) to be non-limiting, representing an effectively unlimited suppy of electrons in the ETL
% Sp = 3 cm/s is found to match Voc

% Support by Christoph Messmer (Fraunhofer ISE) is acknowledged for calibrating this example to the original Sentaurus Device simulations

% this examples uses the pre-bias functionality to represent fast JV-scans for different ion preconditionings
% first a steady-state simulation is performed at the defined pre-bias conditions, to find the ion concentrations
% next a steady-state JV simulation is performed with fixed ions, representing very fast JV-scan speeds which ensure ion-freeze

% (c) 2025 Andreas Fell

SaveSpatial = 1;

Syntax = 'generic';

Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 1;
Domain.Wz = 450 nm; % thickness of perovskite absorber, excluding HTL and ETL thickness

Solver.Electrical.BulkModelType = 'full';
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.VocGuess = 1.2;
Solver.Electrical.IonModelType = 'pre-bias';
Solver.IonPreBias.Type = 'Vterm';
Solver.IonPreBias.Vterm = 0;
Solver.Illumination.Enable = 1;

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'user';
Solver.JVCurve.VtermUser = [1.25:-0.02:-0.1];

Sweep.Enable = 1;
Sweep.NGroups = 1;
Sweep.GroupA(1).Parameter = 'Solver.IonPreBias.Type';
Sweep.GroupA(1).Values = ['OC','MPP','Vterm'];

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 5;
ExternalCircuit.Rshunt = 1e5;
ExternalCircuit.DiodeJ0 = 0;
ExternalCircuit.DiodeIdeality = 2;

Thermal.T = 298.15;

Optical.GenerationModelType = 'defined-generation';
Optical.DefinedGeneration.Type = 'uniform-Jgen';
Optical.DefinedGeneration.UniformJgen = 19.9;
Optical.DefinedGeneration.IlluminationSide = 'front';


Bulk.Material = 'PVK';
Bulk.BackgroundDoping.SettingType = 'NA-ND';
Bulk.BackgroundDoping.NA = 1e10;
Bulk.BackgroundDoping.ND = 1e10;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 1 us;
Bulk.Electrical.Recombination.SRH(1).taup = 1 us;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;
Bulk.Mesh.Quality = 'standard';

SkinFeature(1).Name = 'HTL';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).ElectricalModelType = 'detailed';
SkinFeature(1).Detailed.Mesh.Quality = 'standard';
SkinFeature(1).Layer(1).Name = 'near-surface';
SkinFeature(1).Layer(1).Type = 'near-surface';
SkinFeature(1).Layer(2).Name = 'ITO';
SkinFeature(1).Layer(2).Type = 'transport';
SkinFeature(1).Layer(2).ConductionType = 'p-type';
SkinFeature(1).Layer(2).Thickness = 20nm;
SkinFeature(1).Layer(2).TLModelType = 'metal-like';
SkinFeature(1).Layer(2).Interface.BarrierHeightType = 'from workfunction';
SkinFeature(1).Layer(2).Interface.OhmicResistivity = 1e10;
SkinFeature(1).Layer(2).WorkFunction = 5.9;


SkinFeature(2).Name = 'ETL';
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).ElectricalModelType = 'detailed';
SkinFeature(2).Detailed.Mesh.Quality = 'standard';
SkinFeature(2).Layer(1).Name = 'near-surface';
SkinFeature(2).Layer(1).Type = 'near-surface';
SkinFeature(2).Layer(1).SurfaceRecombination.Type = 'S';
SkinFeature(2).Layer(1).SurfaceRecombination.Sp = 3;
SkinFeature(2).Layer(1).SurfaceRecombination.Sn = 2e7; % thermal velocity, i.e. non-limited by electrons, as electrons are limitless supplied by C60 side of the interface 
SkinFeature(2).Layer(2).Name = 'C60';
SkinFeature(2).Layer(2).Type = 'transport';
SkinFeature(2).Layer(2).ConductionType = 'n-type';
SkinFeature(2).Layer(2).Thickness = 10nm;
SkinFeature(2).Layer(2).Material = 'C60';
SkinFeature(2).Layer(2).TLModelType = 'analytic band-bending';
SkinFeature(2).Layer(2).EactType = 'from DOS and doping';
SkinFeature(2).Layer(2).DopingDensityType = 'user';
SkinFeature(2).Layer(2).DopingDensity = 1e19;
SkinFeature(2).Layer(2).Interface.OhmicResistivity = 1e10;


ContactFeature(1).Name = 'front contact';
ContactFeature(1).Geometry.Plane = 'front';

ContactFeature(2).Name = 'rear contact';
ContactFeature(2).Geometry.Plane = 'rear';

MetalFeature(1).Name = 'front metal';
MetalFeature(1).Geometry.Plane = 'front';
MetalFeature(1).Electrical.Polarity = 'p-type';

MetalFeature(2).Name = 'rear metal';
MetalFeature(2).Geometry.Plane = 'rear';
MetalFeature(2).Electrical.Polarity = 'n-type';

Material.User(1).Name = 'PVK';
Material.User(1).ElectronAffinity = 4.25;
Material.User(1).RelativePermittivity = 24.2;
Material.User(1).BandGap = 1.64;
Material.User(1).Nc = 7e18;
Material.User(1).Nv = 2.5e18;
Material.User(1).ElectronMobility = 2;
Material.User(1).HoleMobility = 2;
Material.User(1).Crad = 0.4899; % 3e-11 cm3/s times ni^2
Material.User(1).nk.n.Type = 'const';
Material.User(1).nk.n.Const = 1;
Material.User(1).nk.k.Type = 'const';
Material.User(1).nk.k.Const = 1;
Material.User(1).IonsEnable = 1;
Material.User(1).N0an = 6e16;
Material.User(1).N0cat = 6e16;
Material.User(1).AnionMobility = 3.86e-8; % 1e-9 / Vt
Material.User(1).CationMobility = 3.86e-14; % 1e-15 / Vt

Material.User(2).Name = 'C60';
Material.User(2).ElectronAffinity = 4.45;
Material.User(2).RelativePermittivity = 5;
Material.User(2).BandGap = 1.97;
Material.User(2).Nc = 9.91e20;
Material.User(2).Nv = 9.91e20;
